task = 'text_classification'

if task == 'text_classification':
    from text_classification.data_utils import DataProcessor
    from configparser import ConfigParser

    parser = ConfigParser()
    res = parser.read('text_classification.cfg')
    
    print(res.sections)




class NlpModel(torch.nn.Module):
    def __init__(self, *args, **kwargs):
        super().__init__()
    
    def forward():
        return NotImplemented0

    def init_model():
        """

        return:
            model instance
        """
        return NotImplemented
    
    def dump_model(dump_dir, dump_model_name):
        return NotImplemented


import os


def read_txt(infile, delimeter=None, maxsplit=-1, remove_newline=True, cols=None, line_limit=None):
    """read text file
    Args:
        infile: input file path
        delimiter
        maxsplit
        remove_newline
        cols: list of index
        num: number of lines that returned
    """

    if cols is not None and type(cols) != list and type(cols) == int:
        raise RuntimeError('cols must be a list or integer')
    if not os.path.exists(infile):
        raise RuntimeError('file not existed: {}'.format(infile))

    content = []
    for l in open(infile, 'r', encoding='utf8'):
        if line_limit is not None and len(content) >= line_limit:
            break
        if remove_newline:
            l = l.rstrip('\n')
        if delimeter is not None:
            l = l.split(delimeter, maxsplit=maxsplit)
            if cols is not None:
                if type(cols) == list:
                    l = [l[index] for index in cols]
                else:  # integer
                    l = l[cols]
        content.append(l)
    return content


def load_txt(infile, delimeter='\t', maxsplit=-1, batch_size=10000, remove_newline=True, cols=None):
    """load text file
    """

    chunk = []
    for l in open(infile, 'r', encoding='utf8'):
        if remove_newline:
            l = l.rstrip('\n')
        if delimeter is not None:
            l = l.split(delimeter, maxsplit=maxsplit)
            if cols is not None:
                if type(cols) == list:
                    l = [l[index] for index in cols]
                else:  # integer
                    l = l[cols]
        chunk.append(l)
        if len(chunk) >= batch_size:
            yield chunk
            chunk = []
    if chunk:
        yield chunk



class Example:
    def __init__(self, text, label1, label2) -> None:
        self.label1, label2


class DataProcessor:
    def __init__(self, line_parser, label_mappings, max_multilabel_nums=[]) -> None:
        self.label_mappings = label_mappings
        self.max_multilabel_nums = max_multilabel_nums
        self.line_parser = line_parser
    

    
class DataProcessor():
    def __init__(self, label_mappings):
        self.label_mappings = label_mappings
    

    def init_tokenizer(str_or_class='bert'):
        return tokenizer
    
    def get_dataloader_from_ann_file(infile):
        return dataloader
    
    def load_dataloader_from_ann_file(infile, chunk):
        yield dataloader

    def get_tensors_from_unann_file(infile):
        pass


def edit_distance(s1, s2):
    m, n = len(s1), len(s2)
    if m == 0 or n == 0:
        return max(m, n)

    dp = [[0]*(n + 1) for _ in range(m + 1)]
    for i in range(m + 1):
        dp[i][0] = i
    for j in range(n + 1):
        dp[0][j] = j

    for i in range(1, m + 1):
        for j in range(1, n + 1):
            if s1[i-1] == s2[j-1]:
                dp[i][j] = dp[i-1][j-1]
            else:
                dp[i][j] = min(dp[i-1][j], dp[i-1][j-1], dp[i][j-1]) + 1

    return dp[m][n]


def longest_common_subsequence(s1, s2):
    m, n = len(s1), len(s2)
    dp = [[0] * (n + 1) for _ in range(m + 1)]

    for i in range(1, m + 1):
        for j in range(1, n + 1):
            if s1[i - 1] == s2[j - 1]:
                dp[i][j] = dp[i - 1][j - 1] + 1
            else:
                dp[i][j] = max(dp[i - 1][j], dp[i][j - 1])

    return dp[m][n]


def longest_common_substring(s1, s2):
    m, n = len(s1), len(s2)
    dp = [[0]*(n+1) for _ in range(m+1)]
    
    for i in range(1, m+1):
        for j in range(1, n+1):
            if s1[i-1] == s2[j-1]:
                dp[i][j] = dp[i-1][j-1] + 1
            else:
                dp[i][j] = 0
    
    return dp[m][n]
